==> mrfDepth_1.0.4.tar.gz: mrfDepth/inst/NEWS.Rd <==
\name{NEWS}
\title{News for package "mrfDepth"}
\encoding{UTF-8}

\section{Changes in version 1.0.4 (2017-06-13)}{
\itemize{
    \item FEATURE: DO or directional outlyingness now available
                   dirOutl, dprojdepth, dprojmedian
    \item FEATURE: functional measures now also have option for directional outlyingness. 
                   fOutl, mfd, mfdmedian
    \item BUGFIX: Call to warning updated in various functions, per new R call
 }
}

\section{Changes in version 1.0.3 (2017-04-01)}{
 \itemize{
    \item FEATURE: Added funtional depth functions: mfd, mfdmedian
    \item FEATURE: Added funtional outlyingness function: fOutl
    \item FEATURE: Added function distSpace
    \item FEATURE: Added the graphical tool FOM
    \item FEATURE: depthContour now also available for p = 1
    \item DOCUMENTATION: Various improvements to several help files
    \item DATA: Added the glass data set
    \item BUGFIX: Changed name of adjOutlyingness to adjOutl to avoid conflict 
                  with the robustbase package. 
    \item BUGFIX: Proper checking of scale for univariate bagdistance added 
    \item BUGFIX: Register native routines and disabled symbol search to fix 
                  warnings in R-devel
 } 
}

\section{Changes in version 1.0.2 (2017-02-01)}{
 \itemize{
    \item FEATURE: Added regression depth functions: rdepth, rdepthmedian and 
          cmltest.
    \item BUGFIX: Fix uninitialized use of variable in HalfSpaceDepthContour2D.f 
          to avoid warnings on fedora (as requested by CRAN).
 } 
}

\section{version 1.0.1 (2017-01-12)}{

 \itemize{
    \item Release on CRAN. 
 }
}

==> mrfDepth_1.0.5.tar.gz: mrfDepth/inst/NEWS.Rd <==
\name{NEWS}
\title{News for package "mrfDepth"}
\encoding{UTF-8}

\section{Changes in version 1.0.5 (2017-10-15)}{
\itemize{
    \item BUGFIX: Bugfix for Solaris as requested by CRAN.
                  -> Fixing "dirOutl.h:85:55: error""
    \item BUGFIX: Bugfix for Windows and Solaris as requested by CRAN.
                  -> Makevars.win file
    \item BUGFIX: Corrections of typos in manuals 
 }
}


\section{Changes in version 1.0.4 (2017-06-13)}{
\itemize{
    \item FEATURE: DO or directional outlyingness now available
                   dirOutl, dprojdepth, dprojmedian
    \item FEATURE: functional measures now also have option for directional outlyingness. 
                   fOutl, mfd, mfdmedian
    \item BUGFIX: Call to warning updated in various functions, per new R call
 }
}

\section{Changes in version 1.0.3 (2017-04-01)}{
 \itemize{
    \item FEATURE: Added funtional depth functions: mfd, mfdmedian
    \item FEATURE: Added funtional outlyingness function: fOutl
    \item FEATURE: Added function distSpace
    \item FEATURE: Added the graphical tool FOM
    \item FEATURE: depthContour now also available for p = 1
    \item DOCUMENTATION: Various improvements to several help files
    \item DATA: Added the glass data set
    \item BUGFIX: Changed name of adjOutlyingness to adjOutl to avoid conflict 
                  with the robustbase package. 
    \item BUGFIX: Proper checking of scale for univariate bagdistance added 
    \item BUGFIX: Register native routines and disabled symbol search to fix 
                  warnings in R-devel
 } 
}

\section{Changes in version 1.0.2 (2017-02-01)}{
 \itemize{
    \item FEATURE: Added regression depth functions: rdepth, rdepthmedian and 
          cmltest.
    \item BUGFIX: Fix uninitialized use of variable in HalfSpaceDepthContour2D.f 
          to avoid warnings on fedora (as requested by CRAN).
 } 
}

\section{version 1.0.1 (2017-01-12)}{

 \itemize{
    \item Release on CRAN. 
 }
}
